<?php
include('config.php');

class Etudiants {

  private $connection = null;

  public function connect($server=LDAP_IP, $port=LDAP_PORT, $user=LDAP_DN_ADMIN, $password=LDAP_PASS){
    if($this->connection){
      return $this->connection;
    } else {
      $ldapConn = ldap_connect($server, $port);
      if($ldapConn){
        ldap_set_option($ldapConn, LDAP_OPT_PROTOCOL_VERSION, 3);
        if(ldap_bind( $ldapConn, $user, $password)){
          $this->connection = $ldapConn;
          return $this->connection;
        }
      }
    }
  }

  public function search($basedn, $filter, $attributes){
    $connection = $this->connect();
    $results = ldap_search($connection, $basedn, $filter, $attributes);
    if($results){
      $entries = ldap_get_entries($connection, $results);
      return $entries;
    }
  }

  public function add($basedn, $uid, $ine, $prenom, $nom, $mail, $password){

    $dn = 'uid='.$uid.','.$basedn;

    $connection = $this->connect();

    $etudiant = array();

    $etudiant['objectclass'][0] = 'top';
    $etudiant['objectclass'][1] = 'person';
    $etudiant['objectclass'][2] = 'organizationalPerson';
    $etudiant['objectclass'][3] = 'inetOrgPerson';
    $etudiant['objectclass'][4] = 'etudiant';

    $etudiant['uid']            = $uid;
    $etudiant['ine']            = $ine;
    $etudiant['givenName']      = $prenom;
    $etudiant['sn']             = $nom;
    $etudiant['mail']           = $mail;
    $etudiant['userPassword']   = $password;
    $etudiant['cn']             = $prenom .' '. $nom;

    $result = ldap_add($connection, $dn, $etudiant);
    if(!result) $this->ldapError();
  }

  public function modify($basedn, $uid, $ine, $prenom, $nom, $mail, $password){

    $dn         = LDAP_DN_ETUDIANT;
    $connection = $this->connect();

    $result     = ldap_search($connection, $dn, "(uid=$uid)");
    if(!$result) $this->ldapError();

    $etudiant = $this->resultToArray($result);

    $etudiant = array();
    $etudiant['ine']            = $ine;
    $etudiant['uid']            = $uid;
    $etudiant['givenName']      = $prenom;
    $etudiant['sn']             = $nom;
    $etudiant['mail']           = $mail;
    $etudiant['displayName']    = $mail;
    $etudiant['userPassword']   = $password;
    $etudiant['cn']             = $prenom .' '. $nom;

    foreach($etudiant as $key => $value){
      if(empty($value)){
        unset($etudiant[$key]);
      }
    }

    $dn      = 'uid='.$uid.','.LDAP_DN_ETUDIANT;
    $result = ldap_modify($connection, $dn, $etudiant);
    if(!$result) $this->ldapError();
  }

  public function delete($dnToDelete){
    $connection = $this->connect();
    $removed = ldap_delete($connection, $dnToDelete);
    if(!$removed){
      $this->ldapError();
    }
  }

  public function ldapError(){
    $connection = $this->connect();
    throw new Exception(
       'Error: ('. ldap_errno($connection) .') '. ldap_error($connection)
    );
  }

  public function resultToArray($result){
    $connection = $this->connect();
    $resultArray = array();

    if($result){
      $entry = ldap_first_entry($connection, $result);
      while ($entry){
        $row = array();
        $attr = ldap_first_attribute($connection, $entry);
        while ($attr){
          $val = ldap_get_values_len($connection, $entry, $attr);
          if(array_key_exists('count', $val) AND $val['count'] == 1){
            $row[strtolower($attr)] = $val[0];
          } else {
            $row[strtolower($attr)] = $val;
          }
          $attr = ldap_next_attribute($connection, $entry);
        }
        $resultArray[] = $row;
        $entry = ldap_next_entry($connection, $entry);
      }
    }
    return $resultArray;
  }

  public function disconnect(){
    $connection = $this->connect();
    ldap_unbind($connection);
  }
}

?>

