<?php

namespace Cnous\PveBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Form\FormError;


use Cnous\PveBundle\Entity\EmailRegistration;
use Cnous\PveBundle\Entity\Usager;
use Cnous\PveBundle\Entity\NProfil;
use Cnous\PveBundle\Entity\NStatutProfil;
use Cnous\PveBundle\Entity\NCivilite;
use Cnous\PveBundle\Entity\NAuteurProfil;

use Cnous\PveBundle\Form\Model\ProfileRegistration;
use Cnous\PveBundle\Form\Type\ProfileRegistrationType;
use Cnous\PveBundle\Form\Model\ProfileConfirmation;
use Cnous\PveBundle\Form\Type\ProfileConfirmationType;
use Cnous\PveBundle\Form\Type\EmailRegistrationType;

use Cnous\PveBundle\Validator\Constraints\UsagerUnique;
use Cnous\PveBundle\Validator\Constraints\ValidINE;

class ProfileController extends Controller
{

    // Action d'affichage du formulaire d'enregistrement via email
    public function registerEmailAction(Request $request)
    {

      $form = $this->getEmailRegistrationForm();

      return $this->render('CnousPveBundle:Profile:register_mail.html.twig', array(
        'form' => $form->createView()
      ));

    }

    // Action de traitement des données envoyées par le formulaire
    // d'inscription via email
    public function processEmailAction(Request $request)
    {

      $form = $this->getEmailRegistrationForm();

      // Gestion de la soumission de la requete
      $form->handleRequest($request);

      // Si le formulaire est invalide, on stoppe & on affiche les erreurs détectées
      // dans celui ci
      if(!$form->isValid()) {
        return $this->render('CnousPveBundle:Profile:register_mail.html.twig', array(
          'form' => $form->createView()
        ));
      }

      // Vérification que l'email n'est pas déja en cours de validation
      $registration = $this->getDoctrine()
        ->getRepository('CnousPveBundle:EmailRegistration')
        ->find($form->getData()->getEmail());

      // Si aucune validation d'email est en cours
      if(!$registration) {
        $registration = $form->getData();
      } else {

        $delay = $this->container->getParameter('pve.registration_min_delay');
        $now = new \DateTime('now');
        $seconds = abs($now->getTimestamp()-$registration->getLastUpdate()->getTimestamp());

        // Si un email a déjà été envoyé il y a "peu" de temps
        if($seconds < $delay) {

          // On affiche le message demandant d'attendre
          $this->addFlash('error', 'CnousPveBundle:Flash:registration_please_wait.txt.twig', array(
            'delay' => new \DateInterval('PT'.($delay-$seconds).'S')
          ));

          return $this->redirect($this->generateUrl('profile_register_email'));

        } else {
          // Sinon on regénère le token
          $registration->regenerate();
        }

      }

      // On sauvegarde le token en BDD
      $em = $this->getDoctrine()->getManager();
      $em->persist($registration);
      $em->flush();

      // Génération de l'URL d'activation a partir du token
      $activationUrl = $this->generateUrl(
        'profile_process_token',
        array(
          'token' => $registration->getToken()
        ),
        true
      );

      // On envoie l'email de validation
      $this->sendMail(
        $registration->getEmail(),
        'PVE: validation de votre adresse email',
        'CnousPveBundle:Mail:registration.txt.twig',
        array(
          'activationUrl' => $activationUrl,
          'registrationType' => $registration->getRegistrationType()
        )
      );

      // On affiche le message de succès
      $this->addFlash('success', 'CnousPveBundle:Flash:email_validation_sent.txt.twig');

      return $this->redirect($this->generateUrl('profile_register_email'));

    }

    // Action de traitement de l'URL de vérification de l'adresse email
    public function processTokenAction($token)
    {

      // On vérifie la validité du token
      $registration = $this->getRegistrationByToken($token);

      // Si celui ci est invalide (n'a pas de correspondance en BDD),
      // on affiche un message d'erreur et on redirige vers le formulaire
      // d'inscription par email
      if(!$registration) {
        $this->addFlash('error', 'CnousPveBundle:Flash:invalid_token.txt.twig');
        return $this->redirect($this->generateUrl('profile_register_email'));
      }

      $registrationType = $registration->getRegistrationType();

      // On génère le formulaire de création de profil
      $form = $this->getProfileRegistrationForm($registrationType, $token);

      // On fait le rendu de la page du formulaire d'enregistrement
      return $this->render('CnousPveBundle:Profile:register_'.$registrationType.'.html.twig', array(
        'form' => $form->createView()
      ));

    }

    // Action de traitement des informations du formulaire de création de profil
    public function processProfileAction($token, $confirm) {

      // On vérifie la validité du token
      $registration = $this->getRegistrationByToken($token);

      // Si celui ci est invalide (n'a pas de correspondance en BDD),
      // on redirige & on affiche un message d'erreur
      if(!$registration) {
        $this->addFlash('error', 'CnousPveBundle:Flash:invalid_token.txt.twig');
        return $this->redirect($this->generateUrl('profile_register_email'));
      }

      $registrationType = $registration->getRegistrationType();
      $isEtudiant = $registrationType == 'etudiant';

      // On récupère le formulaire de création de profil
      $form = $this->getProfileRegistrationForm($registrationType, $token);
      $session = $this->get('session');

      $confirmationType = '';

      if(!empty($confirm)) {
        $data = $session->get('profile_data');
        $confirmationType = $session->get('confirmation_type');
        $session->remove('profile_data');
        $session->remove('confirmation_type');
      } else {
        $form->handleRequest($this->get('request'));
        $data = $form->getData();
      }

      // Si le formulaire est invalide, on renvoie les erreurs à l'utilisateur
      // et on stoppe le traitement
      if(!$confirmationType && !$form->isValid()) {
        // On réaffiche le formulaire avec les erreurs
        return $this->render('CnousPveBundle:Profile:register_'.$registrationType.'.html.twig', array(
          'form' => $form->createView()
        ));
      }

      // Le formulaire est "valide"
      $needConfirm = false;
      $validator = $this->get('validator');
      $usager = $isEtudiant ? $data->getEtudiant()->getUsager() : $data->getUsager();

      // on teste l'unicité de l'utilisateur
      $violations = $validator->validateValue($usager, new UsagerUnique());

      if( $confirmationType != 'unicity' && $violations->count() > 0 ) {
        $needConfirm = true;
        $session->set('confirmation_type', 'unicity'); // On défini un "flag" pour retrouver le type de confirmation
        $usager->setMail($registration->getEmail());
        $this->addFlash('error', 'CnousPveBundle:Flash:profile_confirm_personal_info.txt.twig', array(
          'usager' => $usager
        ));
      }

      // Si c'est un profil étudiant
      if($isEtudiant) {

        $etudiant = $data->getEtudiant();
        $ineEtudiant = $etudiant->getInes()->first();

        // On teste la validité de l'INE
        $violations = $validator->validateValue($ineEtudiant->getIne(), new ValidINE());

        if( $confirmationType != 'ine' && $violations->count() > 0 ) {
          $needConfirm = true;
          $session->set('confirmation_type', 'ine'); // On défini un "flag" pour retrouver le type de confirmation
          // On affiche la page de confirmation
          $this->addFlash('error', 'CnousPveBundle:Flash:profile_confirm_ine.txt.twig', array(
            'etudiant' => $etudiant
          ));
        }

        if($confirmationType == 'ine') {
          $ineEtudiant->setIne($this->generateTempINE($etudiant));
        }

      }

      if( $needConfirm ) {
        // On sauvegarde les informations du formulaire
        $session->set('profile_data', $data);
        return $this->redirect($this->generateUrl('profile_confirm_profile', array(
          'token' => $token
        )));
      }

      // Définition du statut du profil

      switch($confirmationType) {
        case 'unicity':
          // On applique le status d'anomalie "doublon"
          $statusCode = -210;
          break;
        case 'ine':
          // On applique le status d'anomalie
          $statusCode = -200;
          break;
        default:
          $statusCode = $isEtudiant ? 0 : 10; // "Attente validation" ou "OK"
      }

      // On sauvegarde le profil
      try {
        $usager = $this->saveProfile($data, $registration, $statusCode);
      } catch(Exception $e) {
        // TODO gérer l'erreur d'enregistrement et créer un ticket de support
        throw $e; // TEMP
      }

      if($statusCode !== 0 && $statusCode !== 10) {
        // TODO Création du ticket de support suivant le type de statut
      }

      // On supprime l'objet EmailRegistration associé à cette procédure
      // d'inscription
      $em = $this->getDoctrine()->getManager();
      $em->remove($registration);
      $em->flush();

      // On envoie le mail de confirmation & on redirige vers la page d'accueil
      return $this->finishRegistrationAndRedirectToHome($usager);

    }

    public function confirmProfileAction($token) {

      // On vérifie la validité du token
      $registration = $this->getRegistrationByToken($token);

      // Si celui ci est invalide (n'a pas de correspondance en BDD),
      // on redirige & on affiche un message d'erreur
      if(!$registration) {
        $this->addFlash('error', 'CnousPveBundle:Flash:invalid_token.txt.twig');
        return $this->redirect($this->generateUrl('profile_register_email'));
      }

      if(!$this->get('session')->has('profile_data')) {
        return $this->redirect($this->generateUrl('profile_process_token', array(
          'token' => $token
        )));
      }

      $action = $this->generateUrl('profile_process_profile', array(
        'token' => $token,
        'confirm' => 'confirm'
      ));

      $form = $this->createFormBuilder()
        ->setAction($action)
        ->add('confirm', 'submit', array(
          'label' => 'Oui, je confirme ma demande'
        ))
        ->add('cancel', 'button', array(
          'label' => 'Non, je souhaite modifier mes informations'
        ))
        ->getForm();

      return $this->render('CnousPveBundle:Profile:confirm_registration.html.twig', array(
        'form' => $form->createView()
      ));

    }

    /*
     * Helpers
     */

    private function sendMail($dest, $title, $template, $data = array()) {

      // Création du corps de l'email
      $emailBody = $this->renderView($template, $data);

      // On envoie l'email de validation
      $message = \Swift_Message::newInstance()
        ->setSubject($title)
        ->setFrom($this->container->getParameter('pve.email_sender'))
        ->setTo($dest)
        ->setBody($emailBody);

      $this->get('mailer')->send($message);

    }

    private function addFlash($type, $template, $data = array()) {

      $this->get('session')->getFlashBag()->add(
        $type,
        $this->renderView($template, $data)
      );

    }

    // Helper de génération du formulaire d'enregistrement de l'adresse mail
    private function getEmailRegistrationForm() {

      // On créait l'objet formulaire
      $form = $this->createForm(
        new EmailRegistrationType(),
        new EmailRegistration(),
        array(
          'action' => $this->generateUrl('profile_process_email'),
          'csrf_protection' => true
        )
      );

      return $form;

    }

    // Helper de génération du formulaire d'enregistrement du profile
    private function getProfileRegistrationForm($registrationType = '', $token = '') {

      $actionUrl = $this->generateUrl('profile_process_profile', array(
        'token' => $token
      ));

      $profileRegistration = new ProfileRegistration($registrationType);

      // On génère le formulaire de création de profil
      $form = $this->createForm(
        new ProfileRegistrationType($registrationType),
        $profileRegistration,
        array(
          'action' => $actionUrl,
          'csrf_protection' => false
        )
      );

      return $form;

    }

    private function getRegistrationByToken($token) {

      $registration = $this->getDoctrine()
        ->getRepository('CnousPveBundle:EmailRegistration')
        ->findOneByToken($token);

      return $registration;

    }

    private function generateTempINE($etudiant) {

      $code = $etudiant->getEtablissement()->getAcademie()->getCode();
      $date = new \DateTime('now');
      $year = $date->format('y');

      // TODO générer un numéro unique en fonction de l'année & de l'académie
      $sequence = str_pad(rand(0, 99999), 5, 0, STR_PAD_LEFT);

      $key = chr(intval($code . $year . 4 . $sequence) % 23 + 97);

      return $code . $year . 'D' . $sequence . strtoupper($key);
    }

    /*
     * Sauvegarde en BDD les données d'un formulaire de création de profil
     *
     * @param $formData
     * @param $registration
     *
     * @return Usager
     *
     */
    private function saveProfile($data, $registration, $statusCode) {


      $doctrine = $this->getDoctrine();
      $em = $doctrine->getManager();

      $em->getConnection()->beginTransaction();

      try {

        $isEtudiant = $registration->getRegistrationType() === 'etudiant';

        $profil = new NProfil();
        $profil->setCode($isEtudiant ? 1 : 2);

        $statutProfil = new NStatutProfil();
        $statutProfil->setCode($statusCode);

        if($isEtudiant) {
          $usager = $data->getEtudiant()->getUsager();
        } else {
          $usager = $data->getUsager();
        }

        $usager->setProfil($profil);
        $usager->setStatutProfil($statutProfil);
        $usager->setMail($registration->getEmail());

        $usager = $em->merge($usager);
        $em->persist($usager);
        $em->flush();

        if($isEtudiant) {

          $etudiant = $data->getEtudiant();
          $etudiant->setUsager($usager);

          if(!$etudiant->getRepresentantLegal1()->isCompleted()) {
            $etudiant->setRepresentantLegal1(null);
          }

          if(!$etudiant->getRepresentantLegal2()->isCompleted()) {
            $etudiant->setRepresentantLegal2(null);
          }

          $auteurMAJ = new NAuteurProfil();
          $auteurMAJ->setCode('UTILISATEUR');

          $ine = $etudiant->getInes()->first();
          $ine->setAuteurMAJ($auteurMAJ);

          $etudiant = $em->merge($etudiant);
          $em->persist($etudiant);
          $em->flush();

        }

        $em->getConnection()->commit();

      } catch(Exception $e) {
        $em->getConnection()->rollback();
        throw $e;
      }

      return $usager;

    }

    private function finishRegistrationAndRedirectToHome($usager) {

      $passwordResetUrl = $this->getPasswordResetUrl($usager);

      // On envoie l'email de confirmation d'inscription
      $this->sendMail(
        $usager->getMail(),
        'PVE: confirmation de votre inscription',
        'CnousPveBundle:Mail:profile_created.txt.twig',
        array(
          'usager' => $usager,
          'passwordResetUrl' => $passwordResetUrl
        )
      );

      $this->addFlash('success', 'CnousPveBundle:Flash:registration_success.txt.twig');

      return $this->redirect($this->generateUrl('home_index'));

    }

    private function getPasswordResetUrl($usager) {
      return 'TODO';
    }

}
