<?php

namespace Cnous\PveBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
use Cnous\PveBundle\Validator\Constraints as CnousAssert;

/**
 * EmailRegistration
 *
 * @ORM\Table()
 * @ORM\Entity
 *
 */
class EmailRegistration
{
  /**
   * @var string
   *
   * @ORM\Column(name="email", type="string", length=100)
   * @ORM\Id
   * @Assert\Email(message="L'email '{{ value }}' n'est pas valide.")
   * @Assert\Length(
   *    maxMessage="L'adresse email ne peut pas faire plus de 100 caractères.",
   *    max=100
   * )
   * @CnousAssert\UniqueEmail()
   */
  private $email;

  /**
   * @var string
   *
   * @ORM\Column(name="token", type="string", length=50)
   */
  private $token;

  /**
   * @var \DateTime
   *
   * @ORM\Column(name="lastUpdate", type="datetime")
   */
  private $lastUpdate;

  /**
   * @var string
   *
   * @ORM\Column(name="registrationType", type="string", length=10)
   */
  private $registrationType;

  public function __construct() {
    $this->regenerate();
  }

  /**
   * Set email
   *
   * @param string $email
   * @return EmailRegistration
   */
  public function setEmail($email)
  {
    $this->email = $email;
    return $this;
  }

  /**
   * Get email
   *
   * @return string
   */
  public function getEmail()
  {
    return $this->email;
  }

  /**
   * Set registrationType
   *
   * @param string $registrationType
   * @return EmailRegistration
   */
  public function setRegistrationType($registrationType)
  {
    $this->registrationType = $registrationType;
    return $this;
  }

  /**
   * Get registrationType
   *
   * @return string
   */
  public function getRegistrationType()
  {
    return $this->registrationType;
  }

  /**
   * Regenerate the registration token and update the associated timestamp
   *
   * @return EmailRegistration
   */
  public function regenerate() {
    $this->token = bin2hex(openssl_random_pseudo_bytes(25));
    $this->lastUpdate = new \DateTime();
    return $this;
  }

  /**
   * Get token
   *
   * @return string
   */
  public function getToken() {
    return $this->token;
  }

  /**
   * Set lastUpdate
   *
   * @param \DateTime $lastUpdate
   * @return EmailRegistration
   */
  public function setLastUpdate($lastUpdate) {
    $this->lastUpdate = $lastUpdate;

    return $this;
  }

  /**
   * Get lastUpdate
   *
   * @return \DateTime
   */
  public function getLastUpdate() {
    return $this->lastUpdate;
  }

}
