<?php

namespace Cnous\PveBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Etudiant
 *
 * @ORM\Table()
 * @ORM\Entity
 */
class Etudiant
{
    /**
     * @var integer
     *
     * @ORM\OneToOne(targetEntity="Usager", cascade={"all"})
     * @ORM\JoinColumn(name="idEtudiantPVE", referencedColumnName="idPVE")
     * @ORM\Id
     *
     * @Assert\Valid()
     */
    protected $usager;

    /**
     * @var string
     *
     * @ORM\Column(name="idAPB", type="string", length=9, nullable=true)
     *
     * @Assert\Length(max=9, maxMessage="L'identifiant APB ne peut dépasser 9 caractères.")
     */
    protected $idAPB;

    /**
     * @ORM\ManyToOne(targetEntity="NAnnulationAPB", inversedBy="etudiants")
     * @ORM\JoinColumn(name="motifAnnulationAPB", referencedColumnName="code")
     *
     * @Assert\Valid()
     */
    protected $annulationAPB;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dateAnnulationAPB", type="datetime", nullable=true)
     */
    protected $dateAnnulationAPB;

    /**
     * @ORM\ManyToOne(targetEntity="NSituationFamiliale", inversedBy="etudiants", cascade={"merge"})
     * @ORM\JoinColumn(name="codeSituationFamiliale", referencedColumnName="code")
     *
     * @Assert\Valid()
     */
    protected $situationFamiliale;

    /**
     * @ORM\ManyToOne(targetEntity="NPays", inversedBy="etudiants")
     * @ORM\JoinColumn(name="codePaysNationalite", referencedColumnName="codeBCN")
     *
     * @Assert\Valid()
     */
    protected $nationalite;

    /**
     * @ORM\ManyToOne(targetEntity="RepresentantLegal", inversedBy="etudiants", cascade={"all"})
     * @ORM\JoinColumn(name="codeRepresentantLegal1", referencedColumnName="idRepLegal")
     *
     */
    protected $representantLegal1;

    /**
     * @ORM\ManyToOne(targetEntity="RepresentantLegal", inversedBy="etudiants", cascade={"all"})
     * @ORM\JoinColumn(name="codeRepresentantLegal2", referencedColumnName="idRepLegal")
     *
     */
    protected $representantLegal2;

    /**
     * @ORM\ManyToOne(targetEntity="NEtablissement", inversedBy="etudiants", cascade={"merge"})
     * @ORM\JoinColumn(name="origineEtablissement", referencedColumnName="uai")
     *
     * @Assert\Valid()
     */
    protected $etablissement;

    /**
     * @ORM\OneToMany(targetEntity="INEEtudiant", mappedBy="etudiant", cascade={"all"})
     *
     * @Assert\Valid()
     */
    protected $ines;

    public function __construct()
    {
        $this->ines = new ArrayCollection();
    }

    /**
     * Add ines
     *
     * @param \Cnous\PveBundle\Entity\INEEtudiant $ineEtudiant
     * @return Usager
     */
    public function addInes(\Cnous\PveBundle\Entity\INEEtudiant $ineEtudiant)
    {

        $this->ines[] = $ineEtudiant;

        return $this;
    }

    /**
     * Remove ines
     *
     * @param \Cnous\PveBundle\Entity\INEEtudiant $ineEtudiant
     */
    public function removeInes(\Cnous\PveBundle\Entity\INEEtudiant $ineEtudiant)
    {
        $this->ines->removeElement($ineEtudiant);
    }

    /**
     * Get ines
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getInes()
    {
        return $this->ines;
    }

    /**
     * Set idAPB
     *
     * @param string $idAPB
     * @return Etudiant
     */
    public function setIdAPB($idAPB)
    {
        $this->idAPB = $idAPB;

        return $this;
    }

    /**
     * Get idAPB
     *
     * @return string
     */
    public function getIdAPB()
    {
        return $this->idAPB;
    }

    /**
     * Set dateAnnulationAPB
     *
     * @param \DateTime $dateAnnulationAPB
     * @return Etudiant
     */
    public function setDateAnnulationAPB($dateAnnulationAPB)
    {
        $this->dateAnnulationAPB = $dateAnnulationAPB;

        return $this;
    }

    /**
     * Get dateAnnulationAPB
     *
     * @return \DateTime
     */
    public function getDateAnnulationAPB()
    {
        return $this->dateAnnulationAPB;
    }

    /**
     * Set usager
     *
     * @param \Cnous\PveBundle\Entity\Usager $idEtudiantPVE
     * @return Etudiant
     */
    public function setUsager(\Cnous\PveBundle\Entity\Usager $usager)
    {
        $this->usager = $usager;

        return $this;
    }

    /**
     * Get usager
     *
     * @return \Cnous\PveBundle\Entity\Usager
     */
    public function getUsager()
    {
        return $this->usager;
    }

    /**
     * Set annulationAPB
     *
     * @param \Cnous\PveBundle\Entity\NAnnulationAPB $annulationAPB
     * @return Etudiant
     */
    public function setAnnulationAPB(\Cnous\PveBundle\Entity\NAnnulationAPB $annulationAPB = null)
    {
        $this->annulationAPB = $annulationAPB;

        return $this;
    }

    /**
     * Get annulationAPB
     *
     * @return \Cnous\PveBundle\Entity\NAnnulationAPB
     */
    public function getAnnulationAPB()
    {
        return $this->annulationAPB;
    }

    /**
     * Set situationFamiliale
     *
     * @param \Cnous\PveBundle\Entity\NSituationFamiliale $situationFamiliale
     * @return Etudiant
     */
    public function setSituationFamiliale(\Cnous\PveBundle\Entity\NSituationFamiliale $situationFamiliale = null)
    {
        $this->situationFamiliale = $situationFamiliale;

        return $this;
    }

    /**
     * Get situationFamiliale
     *
     * @return \Cnous\PveBundle\Entity\NSituationFamiliale
     */
    public function getSituationFamiliale()
    {
        return $this->situationFamiliale;
    }

    /**
     * Set nationalite
     *
     * @param \Cnous\PveBundle\Entity\NPays $pays
     * @return Etudiant
     */
    public function setNationalite(\Cnous\PveBundle\Entity\NPays $nationalite = null)
    {
        $this->nationalite = $nationalite;

        return $this;
    }

    /**
     * Get nationalite
     *
     * @return \Cnous\PveBundle\Entity\NPays
     */
    public function getNationalite()
    {
        return $this->nationalite;
    }

    /**
     * Set representantLegal1
     *
     * @param \Cnous\PveBundle\Entity\RepresentantLegal $representantLegal1
     * @return Etudiant
     */
    public function setRepresentantLegal1(\Cnous\PveBundle\Entity\RepresentantLegal $representantLegal1 = null)
    {
        $this->representantLegal1 = $representantLegal1;

        return $this;
    }

    /**
     * Get representantLegal1
     *
     * @return \Cnous\PveBundle\Entity\RepresentantLegal
     */
    public function getRepresentantLegal1()
    {
        return $this->representantLegal1;
    }

    /**
     * Set representantLegal2
     *
     * @param \Cnous\PveBundle\Entity\RepresentantLegal $representantLegal2
     * @return Etudiant
     */
    public function setRepresentantLegal2(\Cnous\PveBundle\Entity\RepresentantLegal $representantLegal2 = null)
    {
        $this->representantLegal2 = $representantLegal2;

        return $this;
    }

    /**
     * Get representantLegal2
     *
     * @return \Cnous\PveBundle\Entity\RepresentantLegal
     */
    public function getRepresentantLegal2()
    {
        return $this->representantLegal2;
    }

    /**
     * Set etablissement
     *
     * @param \Cnous\PveBundle\Entity\NEtablissement $etablissement
     * @return Etudiant
     */
    public function setEtablissement(\Cnous\PveBundle\Entity\NEtablissement $etablissement = null)
    {
        $this->etablissement = $etablissement;

        return $this;
    }

    /**
     * Get etablissement
     *
     * @return \Cnous\PveBundle\Entity\NEtablissement
     */
    public function getEtablissement()
    {
        return $this->etablissement;
    }

}
