<?php

namespace Cnous\PveBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * RepresentantLegal
 *
 * @ORM\Table()
 * @ORM\Entity
 *
 */
class RepresentantLegal
{
    /**
     * @var integer
     *
     * @ORM\Column(name="idRepLegal", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $idRepLegal;

    /**
     * @var string
     *
     * @ORM\Column(name="nom", type="string", length=50)
     * @Assert\Blank(groups={"NotCompleted"})
     * @Assert\Regex(
     *  pattern="/^[a-z\-\s]+$/i",
     *  message="Un nom ne peut contenir que des lettres, majuscules ou minuscules, des tirets ou des espaces."
     * )
     * @Assert\NotBlank(message="Le nom ne peut pas être laissé vide.")
     */
    private $nom;

    /**
     * @var string
     *
     * @ORM\Column(name="prenom", type="string", length=50)
     * @Assert\Blank(groups={"NotCompleted"})
     * @Assert\Regex(
     *  pattern="/^[a-z\-]+$/i",
     *  match=true,
     *  message="Un prénom ne peut contenir que des lettres, majuscules ou minuscules ou des tirets."
     * )
     * @Assert\NotBlank(message="Le prénom ne peut pas être laissé vide.")
     * @Assert\Length(max=50, maxMessage="Un prenom ne peut pas faire plus de 50 caractères.")
     */
    private $prenom;

    /**
     * @ORM\ManyToOne(targetEntity="NCivilite", inversedBy="representantsLegaux")
     * @ORM\JoinColumn(name="codeCivilite", referencedColumnName="code")
     */
    private $civilite;

    /**
     * @var string
     *
     * @ORM\Column(name="telephone1", type="string", length=20, nullable=true)
     * @Assert\Length(max=20)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $telephone1;

    /**
     * @var string
     *
     * @ORM\Column(name="telephone2", type="string", length=20, nullable=true)
     * @Assert\Length(max=20)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $telephone2;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseVoie", type="string", length=50, nullable=true)
     * @Assert\Length(max=50)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $adresseVoie;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseComplement1", type="string", length=50, nullable=true)
     * @Assert\Length(max=50)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $adresseComplement1;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseComplement2", type="string", length=50, nullable=true)
     * @Assert\Length(max=50)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $adresseComplement2;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseLocalite", type="string", length=50, nullable=true)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $adresseLocalite;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseCodePostal", type="string", length=10, nullable=true)
     * @Assert\Length(max=10)
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $adresseCodePostal;

    /**
     * @ORM\ManyToOne(targetEntity="NPays", inversedBy="representantsLegaux")
     * @ORM\JoinColumn(name="adresseCodePays", referencedColumnName="codeBCN")
     */
    private $pays;

    /**
     * @var string
     *
     * @ORM\Column(name="mail", type="string", length=100, nullable=true)
     * @Assert\Length(max=50)
     * @Assert\Email(message="L'adresse {{ value }} n'est pas une adresse courriel valide.")
     * @Assert\Blank(groups={"NotCompleted"})
     */
    private $mail;


    /**
     * Get idRepLegal
     *
     * @return integer
     */
    public function getIdRepLegal()
    {
        return $this->idRepLegal;
    }

    /**
     * Set nom
     *
     * @param string $nom
     * @return RepresentantLegal
     */
    public function setNom($nom)
    {
        $this->nom = $nom;

        return $this;
    }

    /**
     * Get nom
     *
     * @return string
     */
    public function getNom()
    {
        return $this->nom;
    }

    /**
     * Set prenom
     *
     * @param string $prenom
     * @return RepresentantLegal
     */
    public function setPrenom($prenom)
    {
        $this->prenom = $prenom;

        return $this;
    }

    /**
     * Get prenom
     *
     * @return string
     */
    public function getPrenom()
    {
        return $this->prenom;
    }

    /**
     * Set telephone1
     *
     * @param string $telephone1
     * @return RepresentantLegal
     */
    public function setTelephone1($telephone1)
    {
        $this->telephone1 = $telephone1;

        return $this;
    }

    /**
     * Get telephone1
     *
     * @return string
     */
    public function getTelephone1()
    {
        return $this->telephone1;
    }

    /**
     * Set telephone2
     *
     * @param string $telephone2
     * @return RepresentantLegal
     */
    public function setTelephone2($telephone2)
    {
        $this->telephone2 = $telephone2;

        return $this;
    }

    /**
     * Get telephone2
     *
     * @return string
     */
    public function getTelephone2()
    {
        return $this->telephone2;
    }

    /**
     * Set adresseVoie
     *
     * @param string $adresseVoie
     * @return RepresentantLegal
     */
    public function setAdresseVoie($adresseVoie)
    {
        $this->adresseVoie = $adresseVoie;

        return $this;
    }

    /**
     * Get adresseVoie
     *
     * @return string
     */
    public function getAdresseVoie()
    {
        return $this->adresseVoie;
    }

    /**
     * Set adresseComplement1
     *
     * @param string $adresseComplement1
     * @return RepresentantLegal
     */
    public function setAdresseComplement1($adresseComplement1)
    {
        $this->adresseComplement1 = $adresseComplement1;

        return $this;
    }

    /**
     * Get adresseComplement1
     *
     * @return string
     */
    public function getAdresseComplement1()
    {
        return $this->adresseComplement1;
    }

    /**
     * Set adresseComplement2
     *
     * @param string $adresseComplement2
     * @return RepresentantLegal
     */
    public function setAdresseComplement2($adresseComplement2)
    {
        $this->adresseComplement2 = $adresseComplement2;

        return $this;
    }

    /**
     * Get adresseComplement2
     *
     * @return string
     */
    public function getAdresseComplement2()
    {
        return $this->adresseComplement2;
    }

    /**
     * Set adresseLocalite
     *
     * @param string $adresseLocalite
     * @return RepresentantLegal
     */
    public function setAdresseLocalite($adresseLocalite)
    {
        $this->adresseLocalite = $adresseLocalite;

        return $this;
    }

    /**
     * Get adresseLocalite
     *
     * @return string
     */
    public function getAdresseLocalite()
    {
        return $this->adresseLocalite;
    }

    /**
     * Set adresseCodePostal
     *
     * @param string $adresseCodePostal
     * @return RepresentantLegal
     */
    public function setAdresseCodePostal($adresseCodePostal)
    {
        $this->adresseCodePostal = $adresseCodePostal;

        return $this;
    }

    /**
     * Get adresseCodePostal
     *
     * @return string
     */
    public function getAdresseCodePostal()
    {
        return $this->adresseCodePostal;
    }

    /**
     * Set mail
     *
     * @param string $mail
     * @return RepresentantLegal
     */
    public function setMail($mail)
    {
        $this->mail = $mail;

        return $this;
    }

    /**
     * Get mail
     *
     * @return string
     */
    public function getMail()
    {
        return $this->mail;
    }

    /**
     * Set civilite
     *
     * @param \Cnous\PveBundle\Entity\NCivilite $civilite
     * @return RepresentantLegal
     */
    public function setCivilite(\Cnous\PveBundle\Entity\NCivilite $civilite = null)
    {
        $this->civilite = $civilite;

        return $this;
    }

    /**
     * Get civilite
     *
     * @return \Cnous\PveBundle\Entity\NCivilite
     */
    public function getCivilite()
    {
        return $this->civilite;
    }

    /**
     * Set pays
     *
     * @param \Cnous\PveBundle\Entity\NPays $pays
     * @return RepresentantLegal
     */
    public function setPays(\Cnous\PveBundle\Entity\NPays $pays = null)
    {
        $this->pays = $pays;

        return $this;
    }

    /**
     * Get pays
     *
     * @return \Cnous\PveBundle\Entity\NPays
     */
    public function getPays()
    {
        return $this->pays;
    }

    public function isCompleted() {
      return $this->getNom() or $this->getPrenom()
        or $this->getMail() or $this->getAdresseCodePostal()
        or $this->getAdresseLocalite() or $this->getAdresseComplement2()
        or $this->getAdresseComplement1() or $this->getAdresseVoie()
        or $this->getTelephone1() or $this->getTelephone2();
    }
}
