<?php

namespace Cnous\PveBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Cnous\PveBundle\Validator\Constraints as CnousAssert;

/**
 * Usager
 *
 * @ORM\Table()
 * @ORM\Entity
 * @ORM\HasLifecycleCallbacks
 *
 */
class Usager
{
    /**
     * @var integer
     *
     * @ORM\Column(name="idPVE", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected $idPVE;

    /**
     * @var string
     *
     * @ORM\Column(name="nom", type="string", length=50)
     * @Assert\Regex(
     *  pattern="/^[a-z\-\s]+$/i",
     *  message="Un nom ne peut contenir que des lettres, majuscules ou minuscules, des tirets ou des espaces."
     * )
     * @Assert\NotBlank(message="Le nom ne peut pas être laissé vide.")
     */
    protected $nom;

    /**
     * @var string
     *
     * @ORM\Column(name="prenom", type="string", length=50)
     * @Assert\Regex(
     *  pattern="/^[a-z\-]+$/i",
     *  match=true,
     *  message="Un prénom ne peut contenir que des lettres, majuscules ou minuscules ou des tirets."
     * )
     * @Assert\NotBlank(message="Le prénom ne peut pas être laissé vide.")
     * @Assert\Length(max=50, maxMessage="Un prenom ne peut pas faire plus de 50 caractères.")
     */
    protected $prenom;

    /**
     * @var string
     *
     * @ORM\Column(name="dateNaissance", type="date")
     * @Assert\Date(message="La date {{ value }} est invalide.")
     */
    protected $dateNaissance;

    /**
     * @var string
     *
     * @ORM\Column(name="prenom2", type="string", length=50, nullable=true)
     * @Assert\Regex(
     *  pattern="/^[a-z\-]+$/i",
     *  message="Un prénom ne peut contenir que des lettres, majuscules ou minuscules ou des tirets."
     * )
     * @Assert\Length(max=50, maxMessage="Un prenom ne peut pas faire plus de 50 caractères.")
     */
    protected $prenom2;

    /**
     * @var string
     *
     * @ORM\Column(name="prenom3", type="string", length=50, nullable=true)
     *
     * @Assert\Regex(
     *  pattern="/^[a-z\-]+$/i",
     *  message="Un prénom ne peut contenir que des lettres, majuscules ou minuscules ou des tirets."
     * )
     * @Assert\Length(max=50, maxMessage="Un prenom ne peut pas faire plus de 50 caractères.")
     */
    protected $prenom3;

    /**
     * @var string
     *
     * @ORM\Column(name="mail", type="string", length=100)
     *
     * @Assert\Email(message="L'adresse '{{ value }}' n'est pas une adresse courriel valide.")
     * @Assert\Length(max=100, maxMessage="une adresse courriel ne peut pas faire plus de 100 caratères.")
     * @CnousAssert\UniqueEmail
     */
    protected $mail;

    /**
     * @var string
     *
     * @ORM\Column(name="telephone1", type="string", length=20)
     *
     * @Assert\Length(max=20, maxMessage="Un numéro de téléphone ne peut pas faire plus de 20 caractères.")
     * @Assert\NotBlank(message="Le numéro de téléphone ne peut être laissé vide.")
     */
    protected $telephone1;

    /**
     * @var string
     *
     * @ORM\Column(name="telephone2", type="string", length=20, nullable=true)
     * @Assert\Length(max=20, maxMessage="Un numéro de téléphone ne peut pas faire plus de 20 caractères.")
     */
    protected $telephone2;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseVoie", type="string", length=50, nullable=true)
     * @Assert\Length(max=50, maxMessage="La voie ne peut pas faire plus de 50 caractères.")
     */
    protected $adresseVoie = null;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseComplement1", type="string", length=50, nullable=true)
     * @Assert\Length(max=50, maxMessage="Le complément d'adresse 1 ne peut pas faire plus de 50 caractères.")
     */
    protected $adresseComplement1 = null;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseComplement2", type="string", length=50, nullable=true)
     * @Assert\Length(max=50, maxMessage="Le complément d'adresse 2 ne peut pas faire plus de 50 caractères.")
     */
    protected $adresseComplement2 = null;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseLocalite", type="string", length=50)
     * @Assert\Length(max=50, maxMessage="La localité ne peut pas faire plus de 50 caractères.")
     */
    protected $adresseLocalite;

    /**
     * @var string
     *
     * @ORM\Column(name="adresseCodePostal", type="string", length=10, nullable=true)
     * @Assert\Length(max=10, maxMessage="Le code postal ne peut pas faire plus de 10 caractères.")
     */
    protected $adresseCodePostal = null;

    /**
     * @ORM\ManyToOne(targetEntity="NPays", inversedBy="usagers", cascade={"all"})
     * @ORM\JoinColumn(name="adresseCodePays", referencedColumnName="codeBCN")
     */
    protected $pays;

    /**
     * @ORM\ManyToOne(targetEntity="NAuteurProfil", inversedBy="usagers", cascade={"merge"})
     * @ORM\JoinColumn(name="auteurCreation", referencedColumnName="code")
     */
    protected $auteurCreation;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dateCreation", type="datetime")
     */
    protected $dateCreation = null;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dateDernierAcces", type="datetime", nullable=true)
     */
    protected $dateDernierAcces;

    /**
     * @ORM\ManyToOne(targetEntity="NStatutProfil", inversedBy="usagers", cascade={"merge"})
     * @ORM\JoinColumn(name="statutProfil", referencedColumnName="code")
     */
    protected $statutProfil;

    /**
     * @ORM\ManyToOne(targetEntity="NProfil", inversedBy="usagers", cascade={"merge"})
     * @ORM\JoinColumn(name="profil", referencedColumnName="code")
     */
    protected $profil;

    /**
     * @ORM\ManyToOne(targetEntity="NCrous", inversedBy="usagers", cascade={"merge"})
     * @ORM\JoinColumn(name="codeCrous", referencedColumnName="code")
     */
    protected $crous;

    /**
     * @ORM\ManyToOne(targetEntity="NCivilite", inversedBy="usagers", cascade={"merge"})
     * @ORM\JoinColumn(name="codeCivilite", referencedColumnName="code")
     * @Assert\Valid()
     */
    protected $civilite;

    /**
     * @ORM\OneToMany(targetEntity="PJInscription", mappedBy="usager", cascade={"all"})
     * @Assert\Valid()
     */
    protected $pJInscriptions;


    public function __construct()
    {
        $this->pJInscriptions = new ArrayCollection();
        $this->setDateCreation(new \DateTime('now'));
    }

    /**
     * @ORM\PrePersist()
     * @ORM\PreUpdate()
     */
    public function updateDateCreation()
    {
      if(!$this->getDateCreation())
      {
        $this->setDateCreation(new \DateTime('now'));
      }
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set nom
     *
     * @param string $nom
     * @return Usager
     */
    public function setNom($nom)
    {
        $this->nom = $nom;

        return $this;
    }

    /**
     * Get nom
     *
     * @return string
     */
    public function getNom()
    {
        return $this->nom;
    }

    /**
     * Set prenom
     *
     * @param string $prenom
     * @return Usager
     */
    public function setPrenom($prenom)
    {
        $this->prenom = $prenom;

        return $this;
    }

    /**
     * Get prenom
     *
     * @return string
     */
    public function getPrenom()
    {
        return $this->prenom;
    }

    /**
     * Set dateNaissance
     *
     * @param string $dateNaissance
     * @return Usager
     */
    public function setDateNaissance($dateNaissance)
    {
        $this->dateNaissance = $dateNaissance;

        return $this;
    }

    /**
     * Get dateNaissance
     *
     * @return string
     */
    public function getDateNaissance()
    {
        return $this->dateNaissance;
    }

    /**
     * Set prenom2
     *
     * @param string $prenom2
     * @return Usager
     */
    public function setPrenom2($prenom2)
    {
        $this->prenom2 = $prenom2;

        return $this;
    }

    /**
     * Get prenom2
     *
     * @return string
     */
    public function getPrenom2()
    {
        return $this->prenom2;
    }

    /**
     * Set prenom3
     *
     * @param string $prenom3
     * @return Usager
     */
    public function setPrenom3($prenom3)
    {
        $this->prenom3 = $prenom3;

        return $this;
    }

    /**
     * Get prenom3
     *
     * @return string
     */
    public function getPrenom3()
    {
        return $this->prenom3;
    }

    /**
     * Set mail
     *
     * @param string $mail
     * @return Usager
     */
    public function setMail($mail)
    {
        $this->mail = $mail;

        return $this;
    }

    /**
     * Get mail
     *
     * @return string
     */
    public function getMail()
    {
        return $this->mail;
    }

    /**
     * Get obfuscated mail
     *
     * @return string
     */
    public function getObfuscatedMail()
    {
        $parts = explode('@', $this->mail);
        $head = $this->obfuscate($parts[0], '*', 2);
        $domain = $this->obfuscate($parts[1], '*', 2);
        return $head . '@' . $domain;
    }

    /**
     * Return an obfuscated string with the given mask and a visible head part

     * @param string $str
     * @param string $mask
     * @param integer $headLength
     * @return string
     */
    private function obfuscate($str, $mask = '*', $headLength = 0) {
      $length = strlen($str);
      if($length <= $headLength) {
        $headLength = 0;
      }
      return substr($str, 0, $headLength) . str_repeat($mask, $length-$headLength);
    }

    /**
     * Set telephone1
     *
     * @param string $telephone1
     * @return Usager
     */
    public function setTelephone1($telephone1)
    {
        $this->telephone1 = $telephone1;

        return $this;
    }

    /**
     * Get telephone1
     *
     * @return string
     */
    public function getTelephone1()
    {
        return $this->telephone1;
    }

    /**
     * Set telephone2
     *
     * @param string $telephone2
     * @return Usager
     */
    public function setTelephone2($telephone2)
    {
        $this->telephone2 = $telephone2;

        return $this;
    }

    /**
     * Get telephone2
     *
     * @return string
     */
    public function getTelephone2()
    {
        return $this->telephone2;
    }

    /**
     * Set adresseVoie
     *
     * @param string $adresseVoie
     * @return Usager
     */
    public function setAdresseVoie($adresseVoie)
    {
        $this->adresseVoie = $adresseVoie;

        return $this;
    }

    /**
     * Get adresseVoie
     *
     * @return string
     */
    public function getAdresseVoie()
    {
        return $this->adresseVoie;
    }

    /**
     * Set adresseComplement1
     *
     * @param string $adresseComplement1
     * @return Usager
     */
    public function setAdresseComplement1($adresseComplement1)
    {
        $this->adresseComplement1 = $adresseComplement1;

        return $this;
    }

    /**
     * Get adresseComplement1
     *
     * @return string
     */
    public function getAdresseComplement1()
    {
        return $this->adresseComplement1;
    }

    /**
     * Set adresseComplement2
     *
     * @param string $adresseComplement2
     * @return Usager
     */
    public function setAdresseComplement2($adresseComplement2)
    {
        $this->adresseComplement2 = $adresseComplement2;

        return $this;
    }

    /**
     * Get adresseComplement2
     *
     * @return string
     */
    public function getAdresseComplement2()
    {
        return $this->adresseComplement2;
    }

    /**
     * Set adresseLocalite
     *
     * @param string $adresseLocalite
     * @return Usager
     */
    public function setAdresseLocalite($adresseLocalite)
    {
        $this->adresseLocalite = $adresseLocalite;

        return $this;
    }

    /**
     * Get adresseLocalite
     *
     * @return string
     */
    public function getAdresseLocalite()
    {
        return $this->adresseLocalite;
    }

    /**
     * Set adresseCodePostal
     *
     * @param string $adresseCodePostal
     * @return Usager
     */
    public function setAdresseCodePostal($adresseCodePostal)
    {
        $this->adresseCodePostal = $adresseCodePostal;

        return $this;
    }

    /**
     * Get adresseCodePostal
     *
     * @return string
     */
    public function getAdresseCodePostal()
    {
        return $this->adresseCodePostal;
    }

    /**
     * Set dateCreation
     *
     * @param \DateTime $dateCreation
     * @return Usager
     */
    public function setDateCreation($dateCreation)
    {
        $this->dateCreation = $dateCreation;

        return $this;
    }

    /**
     * Get dateCreation
     *
     * @return \DateTime
     */
    public function getDateCreation()
    {
        return $this->dateCreation;
    }

    /**
     * Set dateDernierAcces
     *
     * @param \DateTime $dateDernierAcces
     * @return Usager
     */
    public function setDateDernierAcces($dateDernierAcces)
    {
        $this->dateDernierAcces = $dateDernierAcces;

        return $this;
    }

    /**
     * Get dateDernierAcces
     *
     * @return \DateTime
     */
    public function getDateDernierAcces()
    {
        return $this->dateDernierAcces;
    }


    /**
     * Add pJInscriptions
     *
     * @param \Cnous\PveBundle\Entity\PJInscription $pJInscriptions
     * @return Usager
     */
    public function addPJInscription(\Cnous\PveBundle\Entity\PJInscription $pJInscriptions)
    {
      $this->pJInscriptions[] = $pJInscriptions;
      return $this;
    }

    /**
     * Remove pJInscriptions
     *
     * @param \Cnous\PveBundle\Entity\PJInscription $pJInscriptions
     */
    public function removePJInscription(\Cnous\PveBundle\Entity\PJInscription $pJInscriptions)
    {
        $this->pJInscriptions->removeElement($pJInscriptions);
    }

    /**
     * Get pJInscriptions
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getPJInscriptions()
    {
        return $this->pJInscriptions;
    }

    /**
     * Set crous
     *
     * @param \Cnous\PveBundle\Entity\NCrous $crous
     * @return Usager
     */
    public function setCrous(\Cnous\PveBundle\Entity\NCrous $crous = null)
    {
        $this->crous = $crous;

        return $this;
    }

    /**
     * Get crous
     *
     * @return \Cnous\PveBundle\Entity\NCrous
     */
    public function getCrous()
    {
        return $this->crous;
    }

    /**
     * Set auteurCreation
     *
     * @param \Cnous\PveBundle\Entity\NAuteurProfil $auteurCreation
     * @return Usager
     */
    public function setAuteurCreation(\Cnous\PveBundle\Entity\NAuteurProfil $auteurCreation = null)
    {
        $this->auteurCreation = $auteurCreation;

        return $this;
    }

    /**
     * Get auteurCreation
     *
     * @return \Cnous\PveBundle\Entity\NAuteurProfil
     */
    public function getAuteurCreation()
    {
        return $this->auteurCreation;
    }

    /**
     * Set adressePays
     *
     * @param \Cnous\PveBundle\Entity\NPays $adressePays
     * @return Usager
     */
    public function setAdressePays(\Cnous\PveBundle\Entity\NPays $adressePays = null)
    {
        $this->adressePays = $adressePays;

        return $this;
    }

    /**
     * Get adressePays
     *
     * @return \Cnous\PveBundle\Entity\NPays
     */
    public function getAdressePays()
    {
        return $this->adressePays;
    }

    /**
     * Set civilite
     *
     * @param \Cnous\PveBundle\Entity\NCivilite $civilite
     * @return Usager
     */
    public function setCivilite(\Cnous\PveBundle\Entity\NCivilite $civilite = null)
    {
        $this->civilite = $civilite;

        return $this;
    }

    /**
     * Get civilite
     *
     * @return \Cnous\PveBundle\Entity\NCivilite
     */
    public function getCivilite()
    {
        return $this->civilite;
    }

    /**
     * Get idPVE
     *
     * @return integer
     */
    public function getIdPVE()
    {
        return $this->idPVE;
    }

    /**
     * Set pays
     *
     * @param \Cnous\PveBundle\Entity\NPays $pays
     * @return Usager
     */
    public function setPays(\Cnous\PveBundle\Entity\NPays $pays = null)
    {
        $this->pays = $pays;

        return $this;
    }

    /**
     * Get pays
     *
     * @return \Cnous\PveBundle\Entity\NPays
     */
    public function getPays()
    {
        return $this->pays;
    }

    /**
     * Set statutProfil
     *
     * @param \Cnous\PveBundle\Entity\NStatutProfil $statutProfil
     * @return Usager
     */
    public function setStatutProfil(\Cnous\PveBundle\Entity\NStatutProfil $statutProfil = null)
    {
        $this->statutProfil = $statutProfil;

        return $this;
    }

    /**
     * Get statutProfil
     *
     * @return \Cnous\PveBundle\Entity\NStatutProfil
     */
    public function getStatutProfil()
    {
        return $this->statutProfil;
    }

    /**
     * Set profil
     *
     * @param \Cnous\PveBundle\Entity\NProfil $profil
     * @return Usager
     */
    public function setProfil(\Cnous\PveBundle\Entity\NProfil $profil = null)
    {
        $this->profil = $profil;

        return $this;
    }

    /**
     * Get profil
     *
     * @return \Cnous\PveBundle\Entity\NProfil
     */
    public function getProfil()
    {
        return $this->profil;
    }
}
