<?php

namespace Cnous\PveBundle\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Cnous\PveBundle\Entity;
use Cnous\PveBundle\Repository\NPaysRepository;
use Cnous\PveBundle\Form\Type\INEEtudiantType;
use Cnous\PveBundle\Form\Type\UsagerType;
use Cnous\PveBundle\Form\Type\RepresentantLegalType;

class EtudiantType extends AbstractType
{

  private $registrationType;

  public function __construct($registrationType) {
    $this->registrationType = $registrationType;
  }

  public function buildForm(FormBuilderInterface $builder, array $options)
  {

    $pays_query_builder = function(NPaysRepository $npr) {
      return $npr->buildAllOrderedByLibelleLong();
    };

    $builder->add('usager', new UsagerType($this->registrationType));

    $builder->add('situationFamiliale', 'entity', array(
      'label' => 'Situation Familiale',
      'class' => 'CnousPveBundle:NSituationFamiliale',
      'property' => 'libelleCourt',
      'required' => true
    ));

    $builder->add('nationalite', 'entity', array(
      'label' => 'Nationalité',
      'class' => 'CnousPveBundle:NPays',
      'property' => 'libelleLong',
      'query_builder' => $pays_query_builder,
      'required' => true
    ));

    $builder->add('ines', 'collection', array(
      'label' => 'INE',
      'type' => new INEEtudiantType(),
      'allow_add' => false,
      'allow_delete' => false
    ));

    $builder->add('etablissement', 'entity', array(
      'label' => 'Établissement',
      'class' => 'CnousPveBundle:NEtablissement',
      'property' => 'libelleEtablissement',
      'group_by' => 'academie.libelleLong',
      'required' => true
    ));

    $builder->add('representantLegal1', new RepresentantLegalType(), array(
      'required' => false,
      'cascade_validation' => true
    ));

    $builder->add('representantLegal2', new RepresentantLegalType(), array(
      'required' => false,
      'cascade_validation' => true
    ));

  }

  public function setDefaultOptions(OptionsResolverInterface $resolver)
  {
    $resolver
      ->setDefaults(array(
        'data_class' => 'Cnous\PveBundle\Entity\Etudiant',
        'cascade_validation' => true
      ));
  }

  public function getName()
  {
    return 'etudiant';
  }
}
