<?php

namespace Cnous\PveBundle\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Cnous\PveBundle\Entity;
use Cnous\PveBundle\Repository\NPaysRepository;

class UsagerType extends AbstractType
{
  private $registrationType;

  public function __construct($registrationType) {
    $this->registrationType = $registrationType;
  }

  public function buildForm(FormBuilderInterface $builder, array $options)
  {

    $pays_query_builder = function(NPaysRepository $npr) {
      return $npr->buildAllOrderedByLibelleLong();
    };

    $builder->add('civilite', 'entity', array(
      'label' => 'Civilité',
      'class' => 'CnousPveBundle:NCivilite',
      'property' => 'libelleCourt',
      'required' => true
    ));

    $builder->add('nom', 'text', array(
      'label' => 'Nom',
      'required' => true
    ));

    $builder->add('prenom', 'text', array(
      'label' => 'Prénom',
      'required' => true
    ));

    $builder->add('prenom2', 'text', array(
      'label' => 'Deuxième prénom',
      'required' => false
    ));

    $builder->add('prenom3', 'text', array(
      'label' => 'Troisième prénom',
      'required' => false
    ));

    $builder->add('dateNaissance', 'date', array(
      'label' => 'Date de naissance',
      'years' => range(1920, date('Y')),
      'required' => true
    ));

    $builder->add('telephone1', 'text', array(
      'label' => 'Téléphone 1',
      'required' => true
    ));

    $builder->add('telephone2', 'text', array(
      'label' => 'Téléphone 2',
      'required' => false
    ));

    $builder->add('adresseVoie', 'text', array(
      'label' => 'Adresse voie',
      'required' => true
    ));

    $builder->add('adresseComplement1', 'text', array(
      'label' => 'Adresse complément 1',
      'required' => false
    ));

    $builder->add('adresseComplement2', 'text', array(
      'label' => 'Adresse complément 2',
      'required' => false
    ));

    $builder->add('adresseLocalite', 'text', array(
      'label' => 'Ville',
      'required' => true
    ));

    $builder->add('pays', 'entity', array(
      'label' => 'Pays',
      'class' => 'CnousPveBundle:NPays',
      'property' => 'libelleLong',
      'query_builder' => $pays_query_builder,
      'required' => true
    ));

    if($this->registrationType === 'etudiant') {

      $builder->add('pjInscriptions', 'collection', array(
        'label' => 'Pièces justificatives',
        'type' => new PJInscriptionType(),
        'allow_add' => false,
        'allow_delete' => false
      ));

    }

  }

  public function setDefaultOptions(OptionsResolverInterface $resolver)
  {
      $resolver
        ->setDefaults(array(
            'data_class' => 'Cnous\PveBundle\Entity\Usager',
        ));
  }

  public function getName()
  {
    return 'usager';
  }
}
