<?php
namespace Cnous\PveBundle\Validator\Constraints;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

class ValidINEValidator extends ConstraintValidator
{
    protected $allowedPrefixes;
    protected $commonRegex;
    protected $scolarixRegex;
    protected $map;

    public function __construct(array $allowedPrefixes) {
      $this->allowedPrefixes = $allowedPrefixes;
      $this->commonRegex = '/^('.$this->getPrefixesPart().'(\d{2})(\d{6}))([a-z]{1})$/i';
      $this->scolarixRegex = '/^(([0-9a-z]{5})([a-z])(\d{4}))(\d)$/i';
      $this->map = range('a','z');
    }

    public function validate($ine, Constraint $constraint)
    {
      // Si l'INE est vide ou d'une taille incorrecte, on invalide directement celui ci
      if(empty($ine) or strlen($ine) !== 11) {
        $this->context->addViolation($constraint->message, array(
          '%ine%' => $ine
        ));
        return;
      }

      // TODO Vérifier que l'INE n'existe pas déjà en BDD

      // Validation INE suivant règles AGLAE
      // Voir SFD-CRO-001_LOT1_PVE_AGLAE_Cas_dUtilisation_v01.1, section 3.2

      // INAA, APB/SIECLE
      $valid = $this->checkCommonFormat($ine);
      // Scolarix
      if(!$valid) {
        $valid = $this->checkScolarixFormat($ine);
      }

      if(!$valid) {
        $this->context->addViolation($constraint->message, array(
          '%ine%' => $ine
        ));
      }

    }

    private function getPrefixesPart() {
      return '('.join('|', $this->allowedPrefixes).')';
    }

    private function checkCommonFormat($ine) {
      $matches = array();
      $valid = preg_match($this->commonRegex, $ine, $matches);
      if(!$valid) return false;
      $sequence = intval($matches[1]);
      $key = $matches[5];
      return $this->checkCommonKey($sequence, $key);
    }

    private function checkScolarixFormat($ine) {
      $matches = array();
      $valid = preg_match($this->scolarixRegex, $ine, $matches);
      // TODO vérifier le code SISE depuis la BDD ?
      if(!$valid) return false;
      // Si le format est valide, on vérifie la clé
      $sequence = base_convert($matches[1], 36, 10);
      $key = $matches[5];
      return $this->checkScolarixKey($sequence, $key);
    }

    private function checkCommonKey($sequence, $key) {
      $char = $this->map[$sequence % 23];
      return $char == strtolower($key);
    }

    private function checkScolarixKey($sequence, $key) {
      return $sequence % 10 == intval($key);
    }
}
