<?php

namespace Cnous\WebServiceBundle\Controller;

use BeSimple\SoapBundle\ServiceDefinition\Annotation as Soap;
use Symfony\Component\DependencyInjection\ContainerAware;

class AglaeController extends ContainerAware
{
    /**
     * @Soap\Method("lireProfilPVE")
     * @Soap\Param("idEtudiantPVE", phpType = "string")
     * @Soap\Param("ine", phpType = "string")
     * @Soap\Param("contexte", phpType = "BeSimple\SoapCommon\Type\KeyValue\String[]")
     * @Soap\Result(phpType = "BeSimple\SoapCommon\Type\KeyValue\String[]")
     */
    public function lireProfilPVEAction($idEtudiantPVE, $ine, $contexte)
    {
        try {
            $etudiant = $this->container->getDoctrine()->getRepository('CnousPveBundle:Etudiant')->find($idEtudiantPVE);
            $usager = $etudiant->getUsager();
            if (!$etudiant)
                throw new \SoapFault('ETUDIANT_NOT_FOUND', sprintf('Etudiant introuvable, id=%s', $idEtudiantPVE));
            return array(
                'nom'                                => $usager->getNom(),
                'prenom'                             => $usager->getPrenom(),
                'dateNaissance'                      => $usager->getDateNaissance()->format('d/m/Y'),
                'courriel'                           => $usager->getMail(),
                'civilite'                           => $usager->getCivilite()->getCode(),
                'telephone'                          => $usager->getTelephone1(),
                // TODO: Vérifier qu'il ne s'agit pas de l'addresse de l'un des représentantsLégaux
                'adresseDomicileFamilialVoie'        => $usager->getAdresseVoie(),
                'adresseDomicileFamilialComplement1' => $usager->getAdresseComplement1(),
                'adresseDomicileFamilialComplement2' => $usager->getAdresseComplement2(),
                'adresseDomicileFamilialLocalite'    => $usager->getAdresseLocalite(),
                'adresseDomicileFamilialCodePostal'  => $usager->getAdresseCodePostal(),
                'adresseDomicileFamilialCodePays'    => $usager->getPays()->getCodeBCN(),
                'nationalite'                        => $etudiant->getNationalite()->getCodeBCN(),
                'situationFamiliale'                 => $etudiant->getSituationFamiliale()->getCode(),
                'codeRetour'                         => 0
            );
        } catch (Exception $e){
            return array('codeRetour' => 1);
        }
    }

    /**
     * @Soap\Method("goodbye")
     * @Soap\Param("name", phpType = "string")
     * @Soap\Result(phpType = "string")
     */
    public function goodbyeAction($name)
    {
        return $this->container->get('besimple.soap.response')->setReturnValue(sprintf('Goodbye %s!', $name));
    }

    public function testAction()
    {
        $client = new \soapclient('http://localhost/pve/app_dev.php/soap/aglae?wsdl', array(
            'soap_version' => SOAP_1_2,
            'cache_wsdl' => WSDL_CACHE_NONE
        ));

        echo var_dump($client->__getFunctions());
        try {
	    return $client->__soapCall('lireProfilPVE', array('idEtudiantPVE' => 1));
        } catch (Exception $ex) {
            var_dump($ex->faultcode, $ex->faultstring, $ex->faultactor, $ex->detail, $ex->_name, $ex->headerfault);
	}
    }
}

//class AglaeController extends Controller
//{
//    public function indexAction()
//    {
//        ini_set('soap.wsdl_cache_ttl',0);
//        $kernel = $this->get('kernel');
//        $path = $kernel->locateResource('@CnousWebServiceBundle/Resources/public/wsdl/aglae.wsdl');
//
//        $server = new \SoapServer($path);
//        $server->setObject($this->get('cnous_web_service.aglae.lire_profil_pve'));
//
//        $response = new Response();
//        $response->headers->set('Content-Type', 'text/xml; charset=ISO-8859-1');
//
//        ob_start();
//        $server->handle();
//        $response->setContent(ob_get_clean());
//
//        return $response;
//    }
//
//}
